pub fn create_embedder(_config: EmbeddingConfig) -> Box<dyn Embedder>Expand description
Creates an embedder based on whether the feature is enabled and the model exists.
pub fn create_embedder(_config: EmbeddingConfig) -> Box<dyn Embedder>Creates an embedder based on whether the feature is enabled and the model exists.