pub struct SkillWriteRequest {Show 13 fields
pub id: String,
pub name: String,
pub description: Option<String>,
pub version: Option<String>,
pub author: Option<String>,
pub tags: Vec<String>,
pub requires: Vec<String>,
pub allow_tools: Vec<String>,
pub deny_tools: Vec<String>,
pub harness: bool,
pub pool: Option<String>,
pub instructions: String,
pub scope: SkillWriteScope,
}Expand description
Payload for creating or updating a skill on the filesystem skill store.
Fields
id: StringSkill id. If empty, derived from name via slugify_skill_id.
name: Stringdescription: Option<String>version: Option<String>requires: Vec<String>allow_tools: Vec<String>Tools available while this skill is active (empty = no skill tool lock).
deny_tools: Vec<String>harness: boolWhen true, materialize a harness pack for this skill after saving.
pool: Option<String>Optional pool folder id (e.g. navi). Empty = root-level skill.
instructions: StringMarkdown body (instructions). Required non-empty after trim.
scope: SkillWriteScopeTrait Implementations
Sourceimpl Clone for SkillWriteRequest
impl Clone for SkillWriteRequest
Sourceimpl Debug for SkillWriteRequest
impl Debug for SkillWriteRequest
Sourceimpl<'de> Deserialize<'de> for SkillWriteRequest
impl<'de> Deserialize<'de> for SkillWriteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SkillWriteRequest
Sourceimpl PartialEq for SkillWriteRequest
impl PartialEq for SkillWriteRequest
Sourceimpl Serialize for SkillWriteRequest
impl Serialize for SkillWriteRequest
impl StructuralPartialEq for SkillWriteRequest