pub struct AgentRunState {
pub tool_iterations: usize,
pub total_tool_calls: usize,
pub total_tool_errors: usize,
pub consecutive_tool_errors: usize,
pub consecutive_invalid_arguments: usize,
pub consecutive_malformed_arguments: usize,
pub consecutive_unknown_tools: usize,
pub last_tool_signature: Option<String>,
pub repeated_tool_calls: usize,
pub last_failure_kind: Option<ToolFailureKind>,
}Expand description
Mutable state tracked across tool-loop iterations for detecting repetition and enforcing iteration limits.
Fields
tool_iterations: usizeTotal tool-loop iterations so far.
total_tool_calls: usizeTotal tool calls requested so far.
total_tool_errors: usizeTotal failed tool calls so far.
consecutive_tool_errors: usizeConsecutive failed tool calls.
consecutive_invalid_arguments: usizeConsecutive invalid-argument tool calls.
consecutive_malformed_arguments: usizeConsecutive malformed-argument tool calls.
consecutive_unknown_tools: usizeConsecutive unknown-tool calls.
last_tool_signature: Option<String>Hash of the last exact tool invocation signature, for repetition detection.
repeated_tool_calls: usizeConsecutive count of the same repeated tool call.
last_failure_kind: Option<ToolFailureKind>Last classified tool failure kind.