pub enum SecurityRisk {
Tool,
Write,
Command,
GuardedCommand,
ExternalPlugin,
}Expand description
The kind of risk identified by a security check.
Variants
Tool
Any tool execution in restricted mode.
Write
A write operation that modifies the filesystem.
Command
A shell command execution.
GuardedCommand
A guarded command that requires explicit approval outside YOLO mode
(e.g. destructive git operations such as git push / git rebase).
ExternalPlugin
Loading an external native plugin.